@@ -47,7 +47,7 @@ import math
 import os
 import struct
 
-from qtpy.QtCore import QRectF, QSize, QSizeF, Qt
+from qtpy.QtCore import QObject, QRectF, QSize, QSizeF, Qt
 from qtpy.QtGui import (
     QAbstractTextDocumentLayout,
     QColor,
@@ -333,6 +333,13 @@ class QwtPlainTextEngine(QwtTextEngine):
         :param str text: Text to be rendered
         """
         painter.save()
+
+        # Get and configure font for better rendering of rotated text
+        font = painter.font()
+        # Disable hinting to avoid character misalignment in rotated text
+        font.setHintingPreference(QFont.PreferNoHinting)
+        painter.setFont(font)
+
         qwtUnscaleFont(painter)
         painter.drawText(rect, flags, text)
         painter.restore()
@@ -457,8 +464,10 @@ class QwtRichTextEngine(QwtTextEngine):
         return 0, 0, 0, 0
 
 
-class QwtText_PrivateData(object):
+class QwtText_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.renderFlags = Qt.AlignCenter
         self.borderRadius = 0
         self.borderPen = Qt.NoPen
@@ -1104,8 +1113,10 @@ class QwtText(object):
         self.__map.setdefault(format_, engine)
 
 
-class QwtTextLabel_PrivateData(object):
+class QwtTextLabel_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.indent = 4
         self.margin = 0
         self.text = QwtText()
